import { KeybindingContribution, KeybindingRegistry } from '@devpodio/core/lib/browser';
import { CommandContribution, CommandRegistry, Command, MenuContribution, MenuModelRegistry, Disposable } from '@devpodio/core/lib/common';
import { BlameDecorator } from './blame-decorator';
import { EditorManager, EditorWidget, EditorTextFocusContext, StrictEditorTextFocusContext } from '@devpodio/editor/lib/browser';
import { BlameManager } from './blame-manager';
import URI from '@devpodio/core/lib/common/uri';
export declare namespace BlameCommands {
    const TOGGLE_GIT_ANNOTATIONS: Command;
    const CLEAR_GIT_ANNOTATIONS: Command;
}
export declare class BlameContribution implements CommandContribution, KeybindingContribution, MenuContribution {
    protected readonly editorManager: EditorManager;
    protected readonly decorator: BlameDecorator;
    protected readonly blameManager: BlameManager;
    registerCommands(commands: CommandRegistry): void;
    showsBlameAnnotations(uri: string | URI): boolean;
    protected readonly currentFileEditorWidget: EditorWidget | undefined;
    protected isBlameable(uri: string | URI): boolean;
    protected appliedDecorations: Map<string, Disposable>;
    protected showBlame(editorWidget: EditorWidget): Promise<void>;
    protected clearBlame(uri: string | URI): void;
    registerMenus(menus: MenuModelRegistry): void;
    registerKeybindings(keybindings: KeybindingRegistry): void;
}
export declare class BlameAnnotationsKeybindingContext extends EditorTextFocusContext {
    protected readonly blameContribution: BlameContribution;
    protected readonly base: StrictEditorTextFocusContext;
    id: string;
    protected canHandle(widget: EditorWidget): boolean;
}
export declare namespace BlameAnnotationsKeybindingContext {
    const showsBlameAnnotations = "showsBlameAnnotations";
}
