import URI from '@devpodio/core/lib/common/uri';
import { StatefulWidget } from '@devpodio/core/lib/browser';
import { EditorManager, EditorOpenerOptions, EditorWidget, DiffNavigatorProvider } from '@devpodio/editor/lib/browser';
import { GitFileChange, Git, WorkingDirectoryStatus } from '../../common';
import { GitWatcher } from '../../common';
import { GitNavigableListWidget } from '../git-navigable-list-widget';
import { GitFileChangeNode } from '../git-file-change-node';
import { Message } from '@phosphor/messaging';
import * as React from 'react';
export declare const GIT_DIFF = "git-diff";
export declare class GitDiffWidget extends GitNavigableListWidget<GitFileChangeNode> implements StatefulWidget {
    protected readonly GIT_DIFF_TITLE = "Diff";
    protected fileChangeNodes: GitFileChangeNode[];
    protected options: Git.Options.Diff;
    protected gitStatus?: WorkingDirectoryStatus;
    protected listView?: GitDiffListContainer;
    protected readonly git: Git;
    protected readonly diffNavigatorProvider: DiffNavigatorProvider;
    protected readonly editorManager: EditorManager;
    protected readonly gitWatcher: GitWatcher;
    constructor();
    protected init(): void;
    protected readonly toRevision: string | undefined;
    protected readonly fromRevision: string | number | undefined;
    setContent(options: Git.Options.Diff): Promise<void>;
    storeState(): object;
    restoreState(oldState: any): void;
    protected onActivateRequest(msg: Message): void;
    protected render(): React.ReactNode;
    protected renderDiffListHeader(): React.ReactNode;
    protected doRenderDiffListHeader(...children: React.ReactNode[]): React.ReactNode;
    protected renderRepositoryHeader(): React.ReactNode;
    protected renderPathHeader(): React.ReactNode;
    protected renderPath(): React.ReactNode;
    protected renderRevisionHeader(): React.ReactNode;
    protected renderRevision(): React.ReactNode;
    protected renderToolbar(): React.ReactNode;
    protected doRenderToolbar(...children: React.ReactNode[]): React.ReactNode;
    protected readonly showPreviousChange: () => void;
    protected doShowPreviousChange(): void;
    protected renderNavigationLeft(): React.ReactNode;
    protected readonly showNextChange: () => void;
    protected doShowNextChange(): void;
    protected renderNavigationRight(): React.ReactNode;
    protected renderFileChangeList(): React.ReactNode;
    protected addGitDiffListKeyListeners: (id: string) => void;
    protected doAddGitDiffListKeyListeners(id: string): void;
    protected renderGitItem(change: GitFileChangeNode): React.ReactNode;
    protected navigateRight(): void;
    protected navigateLeft(): void;
    protected selectNextNode(): void;
    protected selectPreviousNode(): void;
    protected handleListEnter(): void;
    protected openSelected(): void;
    getUriToOpen(change: GitFileChange): URI;
    openChanges(uri: URI, options?: EditorOpenerOptions): Promise<EditorWidget | undefined>;
    openChange(change: GitFileChange, options?: EditorOpenerOptions): Promise<EditorWidget | undefined>;
    protected revealChange(change: GitFileChange): Promise<void>;
}
export declare namespace GitDiffListContainer {
    interface Props {
        id: string;
        files: React.ReactNode[];
        addDiffListKeyListeners: (id: string) => void;
    }
}
export declare class GitDiffListContainer extends React.Component<GitDiffListContainer.Props> {
    protected listContainer?: HTMLDivElement;
    render(): JSX.Element;
    componentDidMount(): void;
    focus(): void;
}
