import { QuickOpenService } from '@devpodio/core/lib/browser/quick-open/quick-open-service';
import { Git, Repository } from '../common';
import { GitRepositoryProvider } from './git-repository-provider';
import { MessageService } from '@devpodio/core/lib/common/message-service';
import { WorkspaceService } from '@devpodio/workspace/lib/browser/workspace-service';
import { FileSystem } from '@devpodio/filesystem/lib/common';
import { GitErrorHandler } from './git-error-handler';
export declare enum GitAction {
    PULL = 0,
    PUSH = 1
}
export declare class GitQuickOpenService {
    protected readonly git: Git;
    protected readonly repositoryProvider: GitRepositoryProvider;
    protected readonly quickOpenService: QuickOpenService;
    protected readonly messageService: MessageService;
    protected readonly workspaceService: WorkspaceService;
    protected readonly fileSystem: FileSystem;
    protected readonly gitErrorHandler: GitErrorHandler;
    constructor(git: Git, repositoryProvider: GitRepositoryProvider, quickOpenService: QuickOpenService, messageService: MessageService, workspaceService: WorkspaceService, fileSystem: FileSystem);
    clone(url?: string, folder?: string, branch?: string): Promise<string | undefined>;
    private buildDefaultProjectPath;
    fetch(): Promise<void>;
    performDefaultGitAction(action: GitAction): Promise<void>;
    push(): Promise<void>;
    pull(): Promise<void>;
    merge(): Promise<void>;
    checkout(): Promise<void>;
    changeRepository(): Promise<void>;
    chooseTagsAndBranches(execFunc: (branchName: string, currentBranchName: string) => void, repository?: Repository | undefined): Promise<void>;
    commitMessageForAmend(): Promise<string>;
    stash(): Promise<void>;
    protected doStashAction(action: 'pop' | 'apply' | 'drop', text: string, getMessage?: () => Promise<string>): Promise<void>;
    applyStash(): Promise<void>;
    popStash(): Promise<void>;
    dropStash(): Promise<void>;
    applyLatestStash(): Promise<void>;
    popLatestStash(): Promise<void>;
    private open;
    private getOptions;
    private getModel;
    private getRepository;
    private getRemotes;
    private getTags;
    private getBranches;
    private getCurrentBranch;
}
