import URI from '@devpodio/core/lib/common/uri';
import { Path } from '@devpodio/core';
export interface WorkingDirectoryStatus {
    readonly exists: boolean;
    readonly changes: GitFileChange[];
    readonly branch?: string;
    readonly upstreamBranch?: string;
    readonly aheadBehind?: {
        ahead: number;
        behind: number;
    };
    readonly currentHead?: string;
    readonly incomplete?: boolean;
}
export declare namespace WorkingDirectoryStatus {
    function equals(left: WorkingDirectoryStatus | undefined, right: WorkingDirectoryStatus | undefined): boolean;
}
export declare enum GitFileStatus {
    'New' = 0,
    'Copied' = 1,
    'Modified' = 2,
    'Renamed' = 3,
    'Deleted' = 4,
    'Conflicted' = 5
}
export declare namespace GitFileStatus {
    const statusCompare: (left: GitFileStatus, right: GitFileStatus) => number;
    const toString: (status: GitFileStatus, staged?: boolean | undefined) => string;
    const toAbbreviation: (status: GitFileStatus, staged?: boolean | undefined) => string;
}
export interface GitFileChange {
    readonly uri: string;
    readonly status: GitFileStatus;
    readonly oldUri?: string;
    readonly staged?: boolean;
}
export interface CommittedFileChange extends GitFileChange {
    readonly commitish: string;
}
export interface Repository {
    readonly localUri: string;
}
export declare namespace Repository {
    function equal(repository: Repository | undefined, repository2: Repository | undefined): boolean;
    function is(repository: Object | undefined): repository is Repository;
    function relativePath(repository: Repository | string, uri: URI | string): Path;
    const sortComparator: (ra: Repository, rb: Repository) => number;
}
export interface Remote {
    readonly name: string;
    readonly fetch: string;
    readonly push: string;
}
export declare enum BranchType {
    Local = 0,
    Remote = 1
}
export interface Branch {
    readonly name: string;
    readonly upstream?: string;
    readonly type: BranchType;
    readonly tip: Commit;
    readonly remote?: string;
    readonly upstreamWithoutRemote?: string;
    readonly nameWithoutRemote: string;
}
export interface Tag {
    readonly name: string;
}
export interface Commit {
    readonly sha: string;
    readonly summary: string;
    readonly body?: string;
    readonly author: CommitIdentity;
    readonly parentSHAs?: string[];
}
export interface CommitWithChanges extends Commit {
    readonly authorDateRelative: string;
    readonly fileChanges: GitFileChange[];
}
export interface CommitIdentity {
    readonly name: string;
    readonly email: string;
    readonly timestamp: string;
}
export interface GitResult {
    readonly stdout: string;
    readonly stderr: string;
    readonly exitCode: number;
}
export interface StashEntry {
    readonly id: string;
    readonly message: string;
}
export declare enum GitError {
    SSHKeyAuditUnverified = 0,
    SSHAuthenticationFailed = 1,
    SSHPermissionDenied = 2,
    HTTPSAuthenticationFailed = 3,
    RemoteDisconnection = 4,
    HostDown = 5,
    RebaseConflicts = 6,
    MergeConflicts = 7,
    HTTPSRepositoryNotFound = 8,
    SSHRepositoryNotFound = 9,
    PushNotFastForward = 10,
    BranchDeletionFailed = 11,
    DefaultBranchDeletionFailed = 12,
    RevertConflicts = 13,
    EmptyRebasePatch = 14,
    NoMatchingRemoteBranch = 15,
    NothingToCommit = 16,
    NoSubmoduleMapping = 17,
    SubmoduleRepositoryDoesNotExist = 18,
    InvalidSubmoduleSHA = 19,
    LocalPermissionDenied = 20,
    InvalidMerge = 21,
    InvalidRebase = 22,
    NonFastForwardMergeIntoEmptyHead = 23,
    PatchDoesNotApply = 24,
    BranchAlreadyExists = 25,
    BadRevision = 26,
    NotAGitRepository = 27,
    CannotMergeUnrelatedHistories = 28,
    LFSAttributeDoesNotMatch = 29,
    BranchRenameFailed = 30,
    PathDoesNotExist = 31,
    InvalidObjectName = 32,
    OutsideRepository = 33,
    LockFileAlreadyExists = 34,
    PushWithFileSizeExceedingLimit = 35,
    HexBranchNameRejected = 36,
    ForcePushRejected = 37,
    InvalidRefLength = 38,
    ProtectedBranchRequiresReview = 39,
    ProtectedBranchForcePush = 40,
    ProtectedBranchDeleteRejected = 41,
    ProtectedBranchRequiredStatus = 42,
    PushWithPrivateEmail = 43
}
export interface GitFileBlame {
    readonly uri: string;
    readonly commits: Commit[];
    readonly lines: CommitLine[];
}
export interface CommitLine {
    readonly sha: string;
    readonly line: number;
}
