import { JsonRpcServer, JsonRpcProxy } from '@devpodio/core';
import { Repository, WorkingDirectoryStatus } from './git-model';
import { Disposable, Event } from '@devpodio/core/lib/common';
export interface GitStatusChangeEvent {
    readonly source: Repository;
    readonly status: WorkingDirectoryStatus;
    readonly oldStatus?: WorkingDirectoryStatus;
}
export declare namespace GitStatusChangeEvent {
    function is(event: any | undefined): event is GitStatusChangeEvent;
}
export interface GitWatcherClient {
    onGitChanged(event: GitStatusChangeEvent): Promise<void>;
}
export declare const GitWatcherServer: unique symbol;
export interface GitWatcherServer extends JsonRpcServer<GitWatcherClient> {
    watchGitChanges(repository: Repository): Promise<number>;
    unwatchGitChanges(watcher: number): Promise<void>;
}
export declare const GitWatcherServerProxy: unique symbol;
export declare type GitWatcherServerProxy = JsonRpcProxy<GitWatcherServer>;
export declare class ReconnectingGitWatcherServer implements GitWatcherServer {
    private readonly proxy;
    private watcherSequence;
    private readonly watchParams;
    private readonly localToRemoteWatcher;
    constructor(proxy: GitWatcherServerProxy);
    watchGitChanges(repository: Repository): Promise<number>;
    unwatchGitChanges(watcher: number): Promise<void>;
    dispose(): void;
    setClient(client: GitWatcherClient): void;
    private reconnect;
    private doWatchGitChanges;
}
export declare const GitWatcherPath = "/services/git-watcher";
export declare class GitWatcher implements GitWatcherClient, Disposable {
    private readonly server;
    private readonly toDispose;
    private readonly onGitEventEmitter;
    constructor(server: GitWatcherServer);
    dispose(): void;
    readonly onGitEvent: Event<GitStatusChangeEvent>;
    onGitChanged(event: GitStatusChangeEvent): Promise<void>;
    watchGitChanges(repository: Repository): Promise<Disposable>;
}
