"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var url = require("url");
var http = require("http");
function fatal(err) {
    console.error('Missing or invalid credentials.');
    console.error(err);
    process.exit(1);
}
var expectedArgvCount = 5;
function main(argv) {
    if (argv.length !== expectedArgvCount) {
        return fatal("Wrong number of arguments. Expected " + expectedArgvCount + ". Got " + argv.length + " instead.");
    }
    if (!process.env['THEIA_GIT_ASKPASS_HANDLE']) {
        return fatal("Missing 'THEIA_GIT_ASKPASS_HANDLE' handle.");
    }
    var handle = process.env['THEIA_GIT_ASKPASS_HANDLE'];
    var _a = url.parse(handle), host = _a.host, hostname = _a.hostname, port = _a.port, protocol = _a.protocol;
    var gitRequest = argv[2];
    var gitHost = argv[4].substring(1, argv[4].length - 2);
    var opts = {
        host: host,
        hostname: hostname,
        port: port,
        protocol: protocol,
        path: '/',
        method: 'POST'
    };
    var req = http.request(opts, function (res) {
        if (res.statusCode !== 200) {
            return fatal("Bad status code: " + res.statusCode + ".");
        }
        var chunks = [];
        res.setEncoding('utf8');
        res.on('data', function (d) { return chunks.push(d); });
        res.on('end', function () {
            var raw = chunks.join('');
            try {
                var result = JSON.parse(raw);
                process.stdout.write(result);
            }
            catch (err) {
                return fatal('Error parsing the response.');
            }
            setTimeout(function () { return process.exit(0); }, 0);
        });
    });
    req.on('error', function (err) { return fatal(err); });
    req.write(JSON.stringify({ gitRequest: gitRequest, gitHost: gitHost }));
    req.end();
}
main(process.argv);
