/// <reference types="node" />
import * as http from 'http';
import { ILogger } from '@devpodio/core/lib/common/logger';
import { Disposable } from '@devpodio/core/lib/common/disposable';
import { MaybePromise } from '@devpodio/core/lib/common/types';
import { Deferred } from '@devpodio/core/lib/common/promise-util';
import { DugiteGitPromptServer } from '../../node/dugite-git-prompt';
export interface AskpassEnvironment {
    readonly GIT_ASKPASS: string;
    readonly ELECTRON_RUN_AS_NODE?: string;
    readonly THEIA_GIT_ASKPASS_NODE?: string;
    readonly THEIA_GIT_ASKPASS_MAIN?: string;
    readonly THEIA_GIT_ASKPASS_HANDLE?: string;
}
export interface Address {
    readonly port: number;
    readonly family: string;
    readonly address: string;
}
export declare class Askpass implements Disposable {
    protected readonly logger: ILogger;
    protected readonly promptServer: DugiteGitPromptServer;
    protected server: http.Server;
    protected serverAddress: Address | undefined;
    protected ready: Deferred<boolean>;
    protected init(): void;
    protected setup(): Promise<Address | undefined>;
    protected onRequest(req: http.ServerRequest, res: http.ServerResponse): void;
    protected prompt(requestingHost: string, request: string): Promise<string>;
    getEnv(): Promise<AskpassEnvironment>;
    dispose(): void;
    protected hostname(): string;
    protected GIT_ASKPASS(): MaybePromise<string>;
    protected ELECTRON_RUN_AS_NODE(): MaybePromise<string | undefined>;
    protected THEIA_GIT_ASKPASS_NODE(): MaybePromise<string | undefined>;
    protected THEIA_GIT_ASKPASS_MAIN(): MaybePromise<string | undefined>;
    protected THEIA_GIT_ASKPASS_HANDLE(): MaybePromise<string | undefined>;
}
